@@ -4,7 +4,7 @@ use strict;
 
 use vars qw($VERSION);
 
-$VERSION = '0.06';
+$VERSION = '0.07';
 
 use Params::Validate qw(validate SCALAR BOOLEAN OBJECT);
 use Roman;
@@ -68,16 +68,25 @@ my $BasicValidate =
                       }
                     },
       locale    => { type => SCALAR | OBJECT,
-                     default => undef },
-      language  => { type => SCALAR | OBJECT,
-                     optional => 1 },
+                      callbacks =>
+                      { "only 'fr' and 'en' possible" =>
+                        sub { ($_[0] eq 'fr') or ($_[0] eq 'en') or ref($_[0]) =~ /(?:en|fr)$/ },
+                      },
+                     default => 'fr' },
     };
 
 my $NewValidate =
     { %$BasicValidate,
       time_zone => { type => SCALAR | OBJECT,
+                      callbacks =>
+                      { "only 'floating' possible" =>
+                        sub { ($_[0] eq 'floating') or ref($_[0]) and $_[0]->is_floating },
+                      },
                      default => 'floating' },
     };
+my $Lastday_validate = { %$BasicValidate };
+delete $Lastday_validate->{day};
+
 # Constructors
 sub new {
     my $class = shift;
@@ -158,16 +167,7 @@ sub from_object {
 
 sub last_day_of_month {
     my $class = shift;
-    my %p = validate( @_,
-                      { year   => { type => SCALAR },
-                        month  => { type => SCALAR },
-                        abt_hour   => { type => SCALAR, optional => 1 },
-                        abt_minute => { type => SCALAR, optional => 1 },
-                        abt_second => { type => SCALAR, optional => 1 },
-                        locale     => { type => SCALAR | OBJECT, optional => 1 },
-                        time_zone  => { type => SCALAR | OBJECT, optional => 1 },
-                      }
-                    );
+    my %p = validate( @_, $Lastday_validate);
     my $day = $p{month} <= 12 ? 30 : $class->_is_leap_year($p{year}) ? 6 : 5;
     return $class->new(%p, day => $day);
 }
@@ -199,6 +199,8 @@ sub set
     return $self;
 }
 
+sub set_time_zone { } # do nothing, only 'floating' allowed
+
 # Internal functions
 use constant REV_BEGINNING => 654415; # RD value for 1 Vendmiaire I in the Revolutionary calendar
 use constant NORMAL_YEAR    => 365;
@@ -419,10 +421,16 @@ sub day_of_month_0 { $_[0]->{local_c}{day} - 1 }
 *mday_0 = \&day_of_month_0;
 
 sub day_of_decade { $_[0]->{local_c}{day} % 10 || 10 }
-*dod  = \&day_of_decade;
+*dod         = \&day_of_decade;
+*dow         = \&day_of_decade;
+*wday        = \&day_of_decade;
+*day_of_week = \&day_of_decade;
 
 sub day_of_decade_0 { ($_[0]->{local_c}{day} - 1) % 10 }
-*dod_0  = \&day_of_decade_0;
+*dod_0         = \&day_of_decade_0;
+*dow_0         = \&day_of_decade_0;
+*wday_0        = \&day_of_decade_0;
+*day_of_week_0 = \&day_of_decade_0;
 
 sub day_name {
     my $self = shift;
@@ -448,6 +456,11 @@ sub feast_short {
 }
 *feast = \&feast_short;
 
+sub _raw_feast {
+  my ($dt) = @_;
+  return $dt->{locale}->_raw_feast($dt);
+}
+
 sub feast_long {
   my ($dt) = @_;
   return $dt->{locale}->feast_long($dt);
@@ -473,7 +486,7 @@ sub mdy {
     $sep = '-' unless defined $sep;
     return sprintf("%0.2d%s%0.2d%s%0.4d",
                    $self->{local_c}{month}, $sep,
-                   $self->{local_c}{day}, $sep,
+                   $self->{local_c}{day},   $sep,
                    $self->year);
 }
 
@@ -481,7 +494,7 @@ sub dmy {
   my ($self, $sep) = @_;
   $sep = '-' unless defined $sep;
   return sprintf("%0.2d%s%0.2d%s%0.4d",
-                 $self->{local_c}{day}, $sep,
+                 $self->{local_c}{day},   $sep,
                  $self->{local_c}{month}, $sep,
                  $self->year);
 }
@@ -494,7 +507,7 @@ sub abt_hms {
   my ($self, $sep) = @_;
   $sep = ':' unless defined $sep;
   return sprintf("%0.2d%s%0.2d%s%0.2d",
-                    $self->{local_c}{abt_hour}, $sep,
+                    $self->{local_c}{abt_hour},   $sep,
                     $self->{local_c}{abt_minute}, $sep,
                     $self->{local_c}{abt_second});
 }
@@ -510,7 +523,7 @@ sub hms {
     my ($self, $sep) = @_;
     $sep = ':' unless defined $sep;
     return sprintf("%0.1d%s%0.2d%s%0.2d",
-                    $self->{local_c}{hour}, $sep,
+                    $self->{local_c}{hour},   $sep,
                     $self->{local_c}{minute}, $sep,
                     $self->{local_c}{second} );
 }
@@ -525,11 +538,17 @@ sub iso8601 {
 
 sub is_leap_year { $_[0]->_is_leap_year($_[0]->year) }
 
-sub decade {
+sub decade_number {
   my $self = shift;
   return 3 * $self->month + int(($self->day - 1) / 10) - 2;
 }
-*decade_number = \&decade;
+*week_number = \&decade_number;
+
+sub decade {
+  my $self = shift;
+  return ($self->year, $self->decade_number);
+}
+*week = \&decade;
 
 #sub time_zone { $_[0]->{tz} }
 
@@ -564,36 +583,36 @@ sub jd {
   return $jd + ($self->{utc_rd_secs} / 86400);
 }
 
-sub mjd { $_[0]->jd - + 2_400_000.5 }
+sub mjd { $_[0]->jd - 2_400_000.5 }
 
 my %formats = (
-      'a' => sub { $_[0]->day_abbr },
-      'A' => sub { $_[0]->day_name },
-      'b' => sub { $_[0]->month_abbr },
-      'B' => sub { $_[0]->month_name },
-#      'c' => sub { $_[0]->strftime($_[0]->{locale}->preferred_datetime_format) },
-      'C' => sub { int($_[0]->year / 100) },
-      'd' => sub { sprintf '%02d', $_[0]->day_of_month },
-      'D' => sub { $_[0]->strftime('%m/%d/%y') },
-      'e' => sub { sprintf('%2d', $_[0]->day_of_month) },
-      'f' => sub { sprintf('%2d', $_[0]->month) },
-      'F' => sub { $_[0]->ymd('-') },
-      'g' => sub { substr($_[0]->year, -2) }
+        'a' => sub { $_[0]->day_abbr }
+      , 'A' => sub { $_[0]->day_name }
+      , 'b' => sub { $_[0]->month_abbr }
+      , 'B' => sub { $_[0]->month_name }
+      , 'c' => sub { $_[0]->strftime( $_[0]->{locale}->default_datetime_format ) }
+      , 'C' => sub { int($_[0]->year / 100) }
+      , 'd' => sub { sprintf '%02d', $_[0]->day_of_month }
+      , 'D' => sub { $_[0]->strftime('%m/%d/%y') }
+      , 'e' => sub { sprintf('%2d', $_[0]->day_of_month) }
+      , 'f' => sub { sprintf('%2d', $_[0]->month) }
+      , 'F' => sub { $_[0]->ymd('-') }
+      , 'g' => sub { substr($_[0]->year, -2) }
       , 'G' => sub { sprintf '%04d', $_[0]->year }
       , 'h' => sub { $_[0]->month_abbr }
       , 'H' => sub { sprintf('%d', $_[0]->hour) }
-      , 'I' => sub { my $h = $_[0]->hour; $h -= 5 if $h >= 5; sprintf('%d', $h) }
+      , 'I' => sub { my $h = $_[0]->hour || 10; sprintf('%d', $h) }
       , 'j' => sub { sprintf '%03d', $_[0]->day_of_year }
       , 'k' => sub { sprintf('%2d', $_[0]->hour) }
-      , 'l' => sub { my $h = $_[0]->hour; $h -= 5 if $h >= 5; sprintf('%2d', $h) }
+      , 'l' => sub { my $h = $_[0]->hour || 10; sprintf('%2d', $h) }
       , 'L' => sub { sprintf '%04d', $_[0]->year }
       , 'm' => sub { sprintf '%02d', $_[0]->month }
       , 'M' => sub { sprintf '%02d', $_[0]->minute }
       , 'n' => sub { "\n" } # should this be OS-sensitive?
-#     , 'p' => sub {    $_[0]->{locale}->am_pm($_[0]) }
-#     , 'P' => sub { lc $_[0]->{locale}->am_pm($_[0]) }
-      , 'p' => sub { $_[0]->hour < 5 ? 'AM' : 'PM' }
-      , 'P' => sub { $_[0]->hour < 5 ? 'am' : 'pm' }
+      , 'p' => sub {    $_[0]->{locale}->am_pm($_[0]) }
+      , 'P' => sub { lc $_[0]->{locale}->am_pm($_[0]) }
+#      , 'p' => sub { $_[0]->hour < 5 ? 'AM' : 'PM' }
+#      , 'P' => sub { $_[0]->hour < 5 ? 'am' : 'pm' }
       , 'r' => sub { $_[0]->strftime('%I:%M:%S %p') }
       , 'R' => sub { $_[0]->strftime('%H:%M') }
       , 's' => sub { $_[0]->epoch }
@@ -601,12 +620,13 @@ my %formats = (
       , 't' => sub { "\t" }
       , 'T' => sub { $_[0]->strftime('%H:%M:%S') }
       , 'u' => sub { sprintf '%2d', $_[0]->day_of_decade },
-      , 'U' => sub { $_[0]->decade }
+      , 'U' => sub { $_[0]->decade_number }
+      , 'V' => sub { $_[0]->decade_number }
       , 'w' => sub { $_[0]->day_of_decade % 10 }
-      , 'W' => sub { $_[0]->decade }
+      , 'W' => sub { $_[0]->decade_number }
       , 'y' => sub { sprintf('%02d', substr( $_[0]->year, -2 )) }
       , 'Y' => sub { sprintf '%04d', $_[0]->year }
-      , 'z' => sub { offset_as_string($_[0]->offset) }
+      , 'z' => sub { DateTime::TimeZone::offset_as_string( $_[0]->offset ) }
       , 'Z' => sub { $_[0]->{tz}->short_name_for_datetime($_[0]) }
       , '+' => sub { '+' }
       , '%' => sub { '%' }
@@ -636,9 +656,11 @@ sub strftime {
       # it defaults to E! because neither %E! nor %! exist.
       $f =~ s/
 	        %([EO]?([%a-zA-Z]))
+              | %{(\w+)}
              /
-                $formats{$1} ? $formats{$1}->($self)
-                             : $formats{$2} ? $formats{$2}->($self) : $1
+              $3 ? ($self->can($3) ? $self->$3() : "\%{$3}")
+                 : ($formats{$1} ? $formats{$1}->($self)
+                             : $formats{$2} ? $formats{$2}->($self) : $1)
              /sgex;
       return $f unless wantarray;
       push @r, $f;
@@ -652,24 +674,11 @@ sub epoch {
   return $greg->epoch;
 }
 
-#sub set_time_zone {
-#    my ($self, $tz) = @_;
-#
-#    my $was_floating = $self->{tz}->is_floating;
-#
-#    $self->{tz} = ref $tz ? $tz : DateTime::TimeZone->new(name => $tz);
-#
-#    if ($self->{tz}->is_floating && ! $was_floating)
-#      { $self->_calc_utc_rd }
-#    elsif (!$was_floating)
-#      { $self->_calc_local_rd }
-#}
-
 sub DefaultLocale {
   'fr'
 }
 
-my %events = ();
+#my %events = ();
 sub on_date {
   my ($dt, $lan) = @_;
   my $locale;
@@ -680,8 +689,6 @@ sub on_date {
     { $locale = $dt->{locale} }
   return $locale->on_date($dt);
 
-  #_load_events() unless %events;
-  #$events{$self->strftime('%m%dE')} || "";
 }
 
 # A module must return a true value. Traditionally, a module returns 1.
@@ -689,337 +696,6 @@ sub on_date {
 "Libert, galit, fraternit
 ou la mort !";
 
-__DATA__
-0101E
-1 Vendmiaire I The French troops enter Savoie
-1 Vendmiaire III The outposts in the woods of Aachen and Reckem are
-taken by the Army of North (Jourdan)
-0101F
-1 Vendmiaire I entre des troupes franaises en Savoie
-1 Vendmiaire III les postes du bois d'Aix-la-Chapelle et de Reckem sont enlevs 
-par l'Arme du Nord (Jourdan)
-0102E
-2 Vendmiaire I Conquest of Chambry
-2 Vendmiaire III The  Costouge redoubt and camp are taken by the Army
-of Eastern Pyrenees (Dugommier).
-2 Vendmiaire V The Army of Italy (Kilmaine) routs the enemy at Governolo.
-0102F
-2 Vendmiaire I conqute de Chambry
-2 Vendmiaire III prise de la redoute et du camp de Costouge par l'Arme des
-Pyrnes orientales (Dugommier).
-2 Vendmiaire V l'Arme d'Italie (Kilmaine) met en droute l'ennemi  Governolo.
-0103E
-3 Vendmiaire IV affair of Garesio (Miolis)
-0103F
-3 Vendmiaire IV affaire de Garesio (Miolis)
-0104E
-4 Vendmiaire II The Army of Alps (Verdelin) takes the entrenchments of
-Chatillon; the Piemontese rout across the Giffe river
-0104F
-4 Vendmiaire II l'Arme des Alpes (Verdelin) enlve de vive force les retranchements
-de Chatillon ; les Pimontais sont mis en droute et repassent la rivire de Giffe.
-0105E
-5 Vendmiaire III The Spanish are defeated in Olia and Monteilla by the
-Army of Eastern Pyrenees (Charlet).
-0105F
-5 Vendmiaire III dfaite des Espagnols  Olia et Monteilla par l'Arme des Pyrnes
-orientales (Charlet).
-0106E
-6 Vendmiaire III Surrender at Crevecoeur to the Army of the North (Delmas)
-6 Vendmiaire III Kayserlautern, Alsborn and other surrounding outposts
-are taken again by the Army of the Rhine (Michaud)
-6 Vendmiaire V The enemy attacks the Arme of Sambre et Meuse (Hardy) at
-Wurstatt, Nider-Ulm, Ober and  Nider-Iogelheim; the attack is repulsed.
-0106F
-6 Vendmiaire III capitulation de Crevecoeur devant l'Arme du Nord (Delmas)
-6 Vendmiaire III reprise de Kayserlautern, d'Alsborn et autres postes environnants
-par l'Arme du Rhin (Michaud)
-6 Vendmiaire V l'ennemi attaque l'Arme de Sambre et Meuse (Hardy) sur les
-points de Wurstatt, Nider-Ulm, Ober et Nider-Iogelheim ; l'attaque est repousse.
-0107E
-7 Vendmiaire I Anselm's troops conquer the city of Nice and the  Montalban fortress. 
-7 Vendmiaire II The Army of Alps (Verdelin) defeats the enemy in the  Sallanges 
-defiles and takes the Saint-Martin redoubt.
-0107F
-7 Vendmiaire I prise de la ville de Nice et de la forteresse de Montalban 
-par les troupes d'Anselme.
-7 Vendmiaire II l'Arme des Alpes (Verdelin) dfait l'ennemi dans les gorges
-de Sallanges et prend la redoute de Saint-Martin.
-0108E
-8 Vendmiaire V 150 men from the Army of Italy sortie from Mantoue to forage.
-They must surrender to the people of Reggio.
-0108F
-8 Vendmiaire V 150 hommes de l'Arme d'Italie font une sortie de Mantoue pour
-se procurer du fourrage. Ils doivent se rendre aux habitants de Reggio.
-0109F
-9 Vendmiaire I  Custines' Frenchs conquer the Spire city after having
-blown the gates with cannon and endured musketry fire in the streets.
-9 Vendmiaire II The Army of Alps (Chamberlhac) takes the entrenchments at
-Mont-Cormet, previously held by Piemontese.
-0109F
-9 Vendmiaire I les Franais de Custines se rendent matres de la ville de Spire
-aprs avoir enfonc les portes  coups de canons et subi un feu de mousqueterie
-dans les rues de la ville.
-9 Vendmiaire II l'Arme des Alpes (Chamberlhac) enlve de vive-force les
-retranchements de Mont-Cormet tenus par les Pimontais.
-0111E
-11 Vendmiaire II Prisy's troops (Army of Alps) take the Valmeyer outpost
-after a bayonet charge, Saint-Andr's and Chamberlhac's troops take the Beaufort
-outpost, General-in-Chief Kellerman's troops take Moutiers and the Saint-Maurice
-town and Ledoyen's troops storm the Madeleine pass outpost. 
-11 Vendmiaire III during the battle of Aldenhoven, the Army of Sambre-et-Meuse
-(Jourdan) routs the coalised troops.
-11 Vendmiaire V the Army of Rhine and Moselle (general-in-chief Moreau, 
-division generals Desaix and Saint-Cyr) attacks on the whole front and routs the enemy.
-0111F
-11 Vendmiaire II les troupes de Prisy de l'Arme des Alpes enlvent le poste
-de Valmeyer  la bayonette, celles de Saint-Andr et de Chamberlhac enlvent
-le poste de Beaufort, celles du gnral-en-chef Kellerman prennent Moutiers et 
-le bourg Saint-Maurice et celles de Ledoyen enlvent de vive force le poste
-du Col de la Madeleine.
-11 Vendmiaire III  la bataille d'Aldenhoven, l'Arme de Sambre-et-Meuse
-(Jourdan) provoque la droute des troupes coalises.
-11 Vendmiaire V l'Arme du Rhin et Moselle (gnral-en-chef Moreau, 
-gnraux de division Desaix et Saint-Cyr) attaque sur toute la ligne et met
-l'ennemi en droute.
-0112E
-12 Vendmiaire II The Spanish troops are repulsed back in their camps in the Boulon 
-and Argels by the Army of Eastern Pyrenees (Delatre).
-12 Vendmiaire III the land of Juliers surrenders to the Army of Sambre-et-Meuse (Jourdan).
-0112F
-12 Vendmiaire II les Espagnols sont forcs dans leurs camps du Boulon 
-et Argels par l'Arme des Pyrnes orientales (Delatre).
-12 Vendmiaire III le pays de Juliers se rend  l'Arme de Sambre-et-Meuse (Jourdan).
-0113E
-13 Vendmiaire I the Austrians must leave the city of  Worms
-and Custines' troops enter the city.
-13 Vendmiaire II Army of Eastern Pyrenees : Dagobert's troops take
-Campredon while the Colioure garrison (Delatre) fights and routs the Spanish cavalry.
-13 Vendmiaire II arrayed in three columns (Lasalle, Mascaron and
-Dat), the Army of Western Pyrenees attacks and takes the Arau and Aure
-valley outposts.
-13 Vendmiaire IV Bonaparte represses a royalist demonstration near Saint-Roch church
-0113F
-13 Vendmiaire I les Autrichiens sont forcs d'vacuer la ville de Worms
-et les troupes de Custines y font leur entre.
-13 Vendmiaire II Arme des Pyrnes orientales : les troupes de Dagobert prennent
-Campredon tandis que la garnison de Colioure (Delatre) combat la cavalerie espagnole
-et la met en droute.
-13 Vendmiaire II l'Arme des Pyrnes occidentales attaque les postes d'Arau
-et de la valle d'Aure sur trois colonnes (Lasalle, Mascaron et Dat) et les enlve.
-13 Vendmiaire IV Bonaparte rprime une manifestation royaliste  l'glise Saint-Roch
-0115E
-15 Vendmiaire III Cologne surrenders to the Army of Sambre-et-Meuse (Jourdan).
-0115F
-15 Vendmiaire III Cologne se rend  l'Arme de Sambre-et-Meuse (Jourdan).
-0116E
-16 Vendmiaire V the enemy, blockaded in Mantoue by the Army of Italy (Sahuguet) 
-attempt a  4,600-troop sortie but fails.
-0116F
-16 Vendmiaire V l'ennemi, bloqu  Mantoue par l'Arme d'Italie (Sahuguet) tente
-une sortie de 4 600 hommes, sortie qui se solde par un chec.
-0117E
-17 Vendmiaire I as the French Army comes near, the  Austrians lift
-the siege of Lille.
-17 Vendmiaire III fight for and capture of Frankenthal by the Army of the Rhine (Desaix)
-0117F
-17 Vendmiaire I  l'approche de l'Arme franaise, les Autrichiens lvent
-prcipitamment le sige de Lille.
-17 Vendmiaire III combat et prise de Frankenthal par l'Arme du Rhin (Desaix)
-0118E
-18 Vendmiaire II bombardment of Lyon, which opens her gates to
-Dubois-de-Cranc's troops.
-18 Vendmiaire III capture of Shelaudenbach and Vollfstein by the Army of the Rhine (Michaud)
-which links with the Army of Moselle in Lautreck.
-0118F
-18 Vendmiaire II bombardement de Lyon qui ouvre ses portes aux troupes de 
-Dubois-de-Cranc.
-18 Vendmiaire III prise de Shelaudenbach et de Vollfstein par l'Arme du Rhin (Michaud)
-et jonction avec l'Arme de la Moselle  Lautreck.
-0119E
-19 Vendmiaire III before Maestricht, the Army of Sambre-et-Meuse (Duhesme) takes back
-the  Mont-Saint-Pierre castle.
-0119F
-19 Vendmiaire III devant Maestricht, l'Arme de Sambre-et-Meuse (Duhesme) reprend
-le chteau de Mont-Saint-Pierre.
-0120E
-20 Vendmiaire III the Army of Moselle (Moreau) marches on Birkenfeldt, Oberstein,
-Kirn and Meisenheim.
-0120F
-20 Vendmiaire III l'Arme de la Moselle (Moreau) marche sur Birkenfeldt, Oberstein,
-Kirn et Meisenheim.
-0121E
-21 Vendmiaire III the Army of the North (Delmas) enters in Bois-le-Duc.
-0121F
-21 Vendmiaire III entre de l'Arme du Nord (Delmas) dans Bois-le-Duc.
-0122E
-22 Vendmiaire I Kellerman forces the Prussians to leave the city of Verdun.
-He enters Verdun and continues his march to the Prussians.
-0122F
-22 Vendmiaire I Kellerman force les Prussiens  vacuer la ville de Verdun.
-Il y entre et poursuit sa marche contre eux.
-0123E
-23 Vendmiaire III the Army of the Rhine (Michaud) takes Otterberg, Rockenhausen, 
-Landsberg, Alzein and Oberhausen.
-0123F
-23 Vendmiaire III l'Arme du Rhin (Michaud) prend Otterberg, Rockenhausen, 
-Landsberg, Alzein et Oberhausen.
-0124E
-24 Vendmiaire II the Army of Moselle (Delaunay) fights and routs the
-Coalised wchich had advanced on Bitche and Rorbach.
-24 Vendmiaire III fight for and capture of Gellheim and Grunstad by
-the Army of the Rhine (Michaud); the Frenchs capture also Frankenthal.
-0124F
-24 Vendmiaire II l'Arme de la Moselle (Delaunay) combat et provoque la retraite
-prcipite des coaliss qui s'taient ports sur Bitche et Rorbach.
-24 Vendmiaire III combat et prise de Gellheim et de Grunstad par 
-l'Arme du Rhin (Michaud) ; les Franais reprennent aussi Frankenthal.
-0125E
-25 Vendmiaire II combat near Sarreguemines; the Army of Moselle (Delaunay)
-repulses the enemy.
-0125F
-25 Vendmiaire II combat prs de Sarreguemines ; l'Arme de la Moselle (Delaunay)
-repousse l'ennemi.
-0126E
-26 Vendmiaire I the Austrians attack and fail several times Hasnon
-(Muller commander), they are repulsed having suffered many losses.
-26 Vendmiaire II the battle of Wattignies near Maubeuge is won
-by the Army of the North (Jourdan) against the Austrians and the blockade of 
-Maubeuge is lifted.
-26 Vendmiaire III The Army of Western Pyrenees (Moncey) takes
-Iraty and the wonderful forges of Egay and Orbaycette.
-26 Vendmiaire III Army of Moselle :  general-in-chief 
-Moreau's troops take Creutznach and Custines' troops take Worms.
-26 Vendmiaire VI Army of Italy: peace traity in Campo-Formio
-near Udine between  general Bonaparte and the plenipotentiaries
-of the Emperor, king of Hungary and Bohemia.
-26 Vendmiaire VI congress in Rastadt to conclude peace between the 
-French Republic and the German Empire.
-0126F
-26 Vendmiaire I les Autrichiens attaquent plusieurs fois inutilement Hasnon
-(Muller commandant) et sont repousss avec perte.
-26 Vendmiaire II la bataille de Wattignies prs de Maubeuge est remporte
-par l'Arme du Nord (Jourdan) sur les Autrichiens et le blocus de Maubeuge est lev.
-26 Vendmiaire III l'Arme des Pyrnes occidentales (Moncey) prend la belle
-mture d'Iraty et les superbes fonderies d'Egay et d'Orbaycette.
-26 Vendmiaire III Arme de la Moselle : les troupes du gnral-en-chef 
-Moreau prennent Creutznach et celles de Custines prennent Worms.
-26 Vendmiaire VI Arme d'Italie : trait de paix dfinitif  Campo-Formio
-prs d'Udine entre le gnral Bonaparte et les plnipotentiaires de l'Empereur,
-roi de Hongrie et de Bohme.
-26 Vendmiaire VI congrs  Rastadt pour la conclusion de la paix entre
-la Rpublique franaise et l'Empire germanique.
-0127E
-27 Vendmiaire II 600 republican troops from the Army of Italy (Dugommier) 
-take a tactical advantage in  Gillette over 4,000 Austrians, Croats and Piemontese
-and repulse them.
-27 Vendmiaire III The Army of Western Pyrenees (Delabare) defeats 7,000 
-Spaniards near Buruet and Almandos.
-27 Vendmiaire III The Army of the Rhine (Michaud) routs the enemy near
-Kircheim and Worms and captures both cities.
-0127F
-27 Vendmiaire II 600 rpublicains de l'Arme d'Italie (Dugommier) remportent
-l'avantage  Gillette sur 4 000 Autrichiens, Croates et Pimontais et les
-repoussent.
-27 Vendmiaire III l'Arme des Pyrnes occidentales (Delabare) dfait 7 000 
-Espagnols prs de Buruet et d'Almandos.
-27 Vendmiaire III l'Arme du Rhin (Michaud) met en droute l'ennemi prs
-de Kircheim et de Worms et prend ces deux villes.
-0128E
-28 Vendmiaire II The Army of Italy (Dugommier) achieves a complete
-victory at Gilette over the Piemontese.
-28 Vendmiaire III The Arme of the North (Souham) defeats the enemy near Nimegen
-and destroys the legion of Rohan.
-28 Vendmiaire V The Army of the Rhin and Moselle (general-in-chief Moreau and
-division general Beaupuis) is attacked in Retzengen and Simonswald, but
-the enemy efforts fail.
-0128F
-28 Vendmiaire II l'Arme d'Italie (Dugommier) remporte
-une victoire complte  Gilette sur les Pimontais.
-28 Vendmiaire III l'Arme du Nord (Souham) dfait l'ennemi prs de Nimgue
-et dtruit la lgion de Rohan.
-28 Vendmiaire V l'Arme du Rhin et Moselle (gnral-en-chef Moreau et
-gnral de division Beaupuis) est attaque  Retzengen et  Simonswald, les 
-efforts des ennemis sont vains.
-0129E
-29 Vendmiaire I The French Army (general-in-chief Custines) forces the
-Austrians to leave Mayence.
-29 Vendmiaire III The Arme of Moselle (Moreau) enters  Bingen
-after having expelled the Prussians from the positions they held before the town.
-29 Vendmiaire V the Army of Italy (Casalta), debarking in Corsica, advances to
-Bastia and expels the English from the fort where they had retired.
-Saint-Florent and Bonifacio also captured.
-0129F
-29 Vendmiaire I l'Arme franaise (gnral-en-chef Custines) force les
-Autrichiens  vacuer Mayence.
-29 Vendmiaire III l'Arme de la Moselle (Moreau) entre dans Bingen
-aprs avoir chass les Prussiens des positions qu'ils tenaient en avant
-de la ville.
-29 Vendmiaire V l'Arme d'Italie (Casalta), dbarque en Corse, se porte
-sur Bastia et chasse les Anglais qui s'taient retirs dans le fort.
-Prise galement des villes de Saint-Florent et de Bonifacio.
-0130E
-30 Vendmiaire II the Army of Western Pyrenees (Poncet) 
-routs three Spanish columns after a five-hour firefight.
-30 Vendmiaire V Army of Sambre and Meuse (general-in-chief Beurnonville,
-division generals Championnet and Grenier): the enemy crosses the Rhine at
-six points from Bacharach up to Andernach and attacks the Neuwied bridgehead 
-but is forced to retreat.
-0130F
-30 Vendmiaire II l'Arme des Pyrnes occidentales (Poncet) met
-en droute trois colonnes espagnoles aprs une fusillade de cinq heures.
-30 Vendmiaire V Arme de Sambre et Meuse (gnral-en-chef Beurnonville,
-gnraux de division Championnet et Grenier) : l'ennemi passe le Rhin sur
-six points depuis Bacharach jusqu' Andernach et attaque la tte de pont
-de Neuwied et est forc  la retraite.
-0218E
-18 Brumaire VIII Bonaparte's coup: end of the Directoire, beginning of the Consulate
-0218F
-18 Brumaire VIII Coup d'tat de Bonaparte : fin du Directoire, dbut du Consulat
-0311E
-11 Frimaire XIII Napolon 1st is crowned Emperor of the French
-11 Frimaire XIV Austerlitz battle: the French army crushes the Austro-Russian army
-0311F
-11 Frimaire XIII Napolon Premier est couronn Empereur des Franais
-11 Frimaire XIV Bataille d'Austerlitz : l'arme franaise crase l'arme austro-russe
-0607E
-7 Ventse X Birth of Victor Hugo
-0607F
-7 Ventse X Naissance de Victor Hugo
-0901F
-1 Prairial VII Birth of Honor de Balzac
-0901E
-1 Prairial VII Naissance d'Honor de Balzac
-0925E
-25 Prairial VIII Battle of Marengo in Italy, Kleber is assassinated in Cairo
-0925F
-25 Prairial VIII Bataille de Marengo en Italie, Klber est assassin au Caire
-1008E
-8 Messidor II Victory of Fleurus by Jourdan. First use of aerial reco, by 
-Captain Coutelle in the balloon "L'Entreprenant".
-1008F
-8 Messidor II Victoire de Fleurus par Jourdan. Premire utilisation de la
-reconnaissance arienne par le capitaine Coutelle,  bord du ballon L'Entreprenant
-1103E
-3 Thermidor III Victory of Hoche at Quiberon against Royalist forces
-1103F
-3 Thermidor III Victoire de Hoche  Quiberon contre les royalistes
-1109E
-9 Thermidor II Demise of Robespierre
-1109F
-9 Thermidor II La chute de Robespierre
-1118E
-18 Thermidor IV Victory of Bonaparte against Wurmser at Castiglione
-1118F
-18 Thermidor IV Victoire de Bonaparte sur Wurmser  Castiglione
-1303E
-Jour du travail V Death of General Hoche
-1303F
-Jour du travail V Mort du gnral Hoche
-1305E
-Jour des rcompenses IV Death of General Marceau, age 27, at Altenkirchen
-1305F
-Jour des rcompenses IV Mort du gnral Marceau, g de 27 ans,  Altenkirchen
 __END__
 
 =head1 NAME
@@ -1124,7 +800,46 @@ C<DateTime.pm> module.
 
 =item * new(...)
 
-Creates a new date object.
+Creates a new date object. This class accepts the following parameters:
+
+=over 4
+
+=item * C<year>
+
+Year number, mandatory. Year 1 corresponds to Gregorian years late 1792 
+and early 1793.
+
+=item * C<month>
+
+Month number, in the range 1..12, plus number 13 to designate the end-of-year
+additional days.
+
+=item * C<day>
+
+Day number, in the range 1..30. In the case of additional days, the range
+is 1..5 or 1..6 depending on the year (leap year or normal).
+
+=item * C<hour>, C<minute>, C<second>
+
+Decimal hour number, decimal minute number and decimal second number.
+The hour is in the 0..9 range, both other parameters are in the 0..99
+range. These parameters cannot be specified with the sexagesimal time
+parameters C<abt_>I<xxx> (see below).
+
+=item * C<abt_hour>, C<abt_minute>, C<abt_second>
+
+Sexagesimal hour number, sexagesimal minute number and sexagesimal second number.
+The hour is in the 0..23 range, both other parameters are in the 0..59
+range. These parameters cannot be specified with the decimal time
+parameters (see above).
+
+=item * C<locale>
+
+Only the values C<fr> (French) and C<en> (English) are allowed. Default
+is French. No other values are possible, even territory variants such
+as C<fr_BE> or C<en_US>.
+
+=back
 
 =item * from_epoch( epoch => $epoch )
 
@@ -1143,11 +858,14 @@ The preferred way for calendar to calendar conversion.
 
 =item * last_day_of_month( ... )
 
-Not tested
+Same as new, except that the C<day> parameter is forbidden and
+is automatically set to the end of the month. If the C<month>
+paramter is 13 for the additional days, the day is set to the
+end of the year, either the 5th or the 6th additional day.
 
 =item * clone
 
-Not tested
+Creates a replica of the original date object.
 
 =item * set( .. )
 
@@ -1180,9 +898,10 @@ at the end of the year, returns 12, which is not really a month number.
 
 =item * month_name
 
-Returns the French  name of the month. No  other language is supported
-yet.  For  the additional days at  the end of the  year, returns "jour
-complmentaire", the translation of "additional day".
+Returns the  French name of the  month or its  English translation. No
+other language is  supported yet.  For the additional  days at the end
+of  the  year,  returns  "jour  complmentaire",  the  translation  of
+"additional day".
 
 Note: The  English translations for  the month names come  from Thomas
 Carlyle's book.
@@ -1197,9 +916,11 @@ were also known as the I<Sans-culottides>.
 
 Returns the day of the month, from 1..30.
 
-=item * day_of_decade, dod
+=item * day_of_decade, dod, day_of_week, dow, wday
 
-Returns the day of the decade, from 1..10.
+Returns the day of the decade, from 1..10. The C<dow>, C<wday> and C<day_of_week>
+names are there for compatibility's sake with C<DateTime>, even if the word
+"week" is improper.
 
 =item * day_name
 
@@ -1264,19 +985,22 @@ specified for the Gregorian calendar.
 
 Returns a true value if the year is a leap year, false else.
 
-=item * decade, decade_number
+=item * decade_number, week_number
 
-Returns the I<dcade> number. Note: since the I<dcades> are aligned
-with the years, there is no need for a method giving the year of the
-week... er I mean I<dcade>. So the methods C<decade> and C<decade_number>
-are synonymous. Especially, the C<decade> method returns a scalar, not
-a 2-element list.
+Returns the I<dcade> number.
+
+=item * decade, week
+
+Returns a 2-element list, with the year number and the decade number.
+Since the I<dcade> is always aligned with a month and then with a 
+year, the year element is always the same as the date's year.
+Anyhow, this is done for compatibility with DateTime's C<week> method.
 
 =item * utc_rd_values
 
-Returns the current UTC Rata Die days and seconds as a two element
-list.  This exists primarily to allow other calendar modules to create
-objects based on the values provided by this object.
+Returns the  current UTC Rata Die  days, seconds and  nanoseconds as a
+3-element list.  This exists primarily to allow other calendar modules
+to create objects based on the values provided by this object.
 
 =item * jd, mjd
 
@@ -1304,10 +1028,11 @@ of all possible format specifiers.
 
 =item * epoch
 
-Return the UTC epoch value for the datetime object.  Internally, this
-is implemented using C<Time::Local>, which uses the Unix epoch even on
-machines with a different epoch (such as Mac OS).  Datetimes before the
-start of the epoch will be returned as a negative number.
+Return the UTC epoch value  for the datetime object.  Internally, this
+is  implemented  C<expoch>  from  C<DateTime>,  which  in  turn  calls
+C<Time::Local>,  which uses  the Unix  epoch even  on machines  with a
+different epoch (such  as Mac OS).  Datetimes before  the start of the
+epoch will be returned as a negative number.
 
 Since epoch times cannot represent many dates on most platforms, this
 method may simply return undef in some cases.
@@ -1319,10 +1044,11 @@ another source of bugs.
 
 =item * on_date
 
-Gives a few historical events that took place on the same date (day+month).
-These events occur during the period of use of the calendar, that is,
-no later than Gregorian year 1805. The related events either were
-located in France, or were battles in which a French army was involved.
+Gives  a  few historical  events  that took  place  on  the same  date
+(day+month, irrespective of the  year).  These events occur during the
+period of use  of the calendar, that is, no  later than Gregorian year
+1805. The  related  events either  were  located  in  France, or  were
+battles in which a French army was involved.
 
 This  method accepts  one  optional argument,  the  language. For  the
 moment, only  "en" for English and  "fr" for French  are available. If
@@ -1405,10 +1131,8 @@ The result is a single-char string.
 
 =item * %I
 
-The hour as a decimal number using a 5-hour clock (range 0 to 4).
-Since decimal time was never actually used, we do not know whether the 
-people would have split a day in two halves. This format is provided
-by analogy with the usage of sexagesimal time in the Gregorian calendar.
+The hour as a decimal number using the numbers on a clockface, that
+is, range 1 to 10. The result is a single-char string, except for 10.
 
 =item * %j
 
@@ -1421,12 +1145,13 @@ the result is a 2-char string, the digit is preceded by a blank. (See also %H.)
 
 =item * %l
 
-The hour (5-hour clock) as a decimal number (range 1 to 4); the result
-is a 2-char string, the digit is preceded by a blank. (See also %I.)
+The hour as read from a clockface (range 1 to 10). The result is
+a  2-char string, the digit is preceded by a blank, except of course
+for 10. (See also %I.)
 
 =item * %m
 
-The month as a decimal number (range 01 to 12).
+The month as a decimal number (range 01 to 13).
 
 =item * %M
 
@@ -1481,15 +1206,14 @@ also %w.
 =item * %U
 
 The I<dcade> number of the current year as a decimal number, range 00
-to 31.
+to 37.
 
 =item * %V
 
-to be adapted to FR calendar.
-The ISO 8601:1988 week number of the current year as a decimal number,
-range 01 to 53, where week 1 is the first week that has at least 4
-days in the current year, and with Monday as the first day of the
-week. See also %U and %W.
+The decade number (French Revolutionary equivalent to
+the ISO 8601:1988 week number) of the current year as a decimal number,
+range 01 to 37. Identical to %U, since dcades are aligned with the
+beginning of the year.
 
 =item * %w
 
@@ -1499,7 +1223,7 @@ also %u.
 =item * %W
 
 The I<dcade> number of the current year as a decimal number, range 00
-to 31.
+to 37.
 
 =item * %y
 
@@ -1563,6 +1287,8 @@ Some feast names are not translated, other's translations are doubtful
 Support for this module is provided via the datetime@perl.org email
 list. See L<http://lists.perl.org/> for more details.
 
+Please enter bug reports at L<http://rt.cpan.org/>
+
 =head1 AUTHOR
 
 Jean Forget <JFORGET@cpan.org>
@@ -1605,7 +1331,7 @@ http://www.kokogiak.com/frc/default.asp
 
 =head1 LICENSE STUFF
 
-Copyright (c) 2003 Jean Forget. All rights reserved. This program is
+Copyright (c) 2003--2004 Jean Forget. All rights reserved. This program is
 free software. You can distribute, modify, and otherwise mangle
 DateTime::Calendar::FrenchRevolutionary under the same terms as perl.
 
